#ifndef HEADER_COMMAND
#define HEADER_COMMAND

/* The first argument is the pathname to the window the command originated
   in, and is null if from no window.  The second argument is the command
   to parse. */
int do_command(const char *, const char *);

#endif
